#!/bin/bash
#
# gitlab-tools:bin/git-api/git-api.sh
#

# Return git main repositories and submodules directories
function find_git_directories {
  local -r sources_home="$1"

  find "${sources_home}" -name .git -exec dirname "{}" \; | sort | uniq
}

function get_remote_url {
  local -r git_directory="$1"
  local -r remote_name="$2"

  cd "${git_directory}" && git remote get-url "${remote_name}"
}

function get_all_remote {
  local -r git_directory="$1"

  cd "${git_directory}" && git remote
}

function git_clone {
  local -r bare="$1"
  local -r url="$2"
  local -r ssh_key="${3:-}"
  local -a cmd=()

  if [ -n "${bare}" ] ; then
    cmd+=( "${bare}" )
  fi

  cmd+=( "${url}" )

  cat <<EOF
  git clone ${cmd[@]}
EOF

  (
    if [ -n "${ssh_key}" ] ; then
      export GIT_SSH_COMMAND="/usr/bin/ssh -i ${ssh_key}"
    fi

    git clone "${cmd[@]}"
  )

  local -ri clone_rc=$?

  if [ "${clone_rc}" -ne 0 ] ; then
    echo "*** Error while clonning: ${url}"
    exit 1
  fi
}
