#!/bin/bash
#
# gitlab-tools:bin/gitlab-bash-api/get.sh
#
# Based on GitLab documentation:
#  https://docs.gitlab.com/ee/api/
#  https://docs.gitlab.com/ce/api/
#  https://gitlab.com/gitlab-org/gitlab-ce/tree/master/lib/api
#  https://docs.gitlab.com/ce/api/projects.html
#
if [ "$( type -t normalize_uri )" != 'function' ] ; then
  # shellcheck disable=SC1090
  source "$( dirname "${BASH_SOURCE[0]}" )/utils.sh" || exit 1
fi

declare NEXT_PAGE=

#
# HTTP GET - Read one page
#
function __gitlab_get_page__ {
  local -r api_uri="$1"
  local -r api_params="$2"
  local -r page="$3"
  local -r curl_url="${GITLAB_URL_PREFIX}/api/${GITLAB_API_VERSION}/${api_uri}?page=${page}&per_page=${PER_PAGE_MAX}&${api_params}"
  local    curl_result=

  if [ "${GITLAB_DEBUG}" = 'true' ] ; then
    cat <<EOF >&2
    curl --location --include --silent --header "PRIVATE-TOKEN: ${GITLAB_PRIVATE_TOKEN}" "${curl_url}"
EOF
  fi

  curl_result="$(
    curl --location --include --silent --header "PRIVATE-TOKEN: ${GITLAB_PRIVATE_TOKEN}" "${curl_url}"
    )"
  local curl_rc=$?

#echo "${curl_result}" >curl_result.txt
#exit 1

  if [ ${curl_rc} -ne 0 ]; then
    echofatal "Error curl status ${curl_rc} : curl_url=${curl_url}" >&2
    return 1
  fi

  local head='true'
  local body=
  local header=
  local line=

  while read -r line; do
    if ${head} ; then
      if [[ "${line}" = "${CR}" ]]; then
        head='false'
      else
        header="${header}${LF}${line}"
      fi
    else
      if [ -z "${body}" ]; then
        body="${line}"
      else
        body="${body}${LF}${line}"
      fi
    fi
  done < <( echo "${curl_result}" )

  NEXT_PAGE="$( echo "${header}" | grep 'X-Next-Page:' | cut -c 14-| tr -d '[:space:]' )"
  PAGE_BODY="${body}"

  return 0
}

#
# HTTP GET - Read all pages
#
function gitlab_get_raw {
  local -r api_uri="$1"
  local -r api_params="$2"
  local -i page=1
  local    json=
  local    begin=

  NEXT_PAGE='*'

  while [[ ${page} =~ ^-?[0-9]+$ ]] && [ "${page}" != '0' ]; do
    __gitlab_get_page__ "${api_uri}" "${api_params}" "${page}" || return $?

    if [ -n "${json}" ] ; then
      json+=','
    fi

    begin="$( echo "${PAGE_BODY}" | cut -b1 )"
    if [ "${begin}" = '[' ] ; then
      json+="$( echo "${PAGE_BODY}" | cut -b2- | rev | cut -b2- | rev )"
    else
      json+="${PAGE_BODY}"
    fi

     page="${NEXT_PAGE}"
  done

  if [ "${begin}" = '[' ] ; then
    echo "[${json}]"
  else
    echo "${json}"
  fi
}

#
# API: gitlab_get - HTTP GET - Read all pages
#
function gitlab_get {
  local -r api_uri="$1"
  local -r api_params="$2"

  gitlab_get_raw "$( normalize_uri "${api_uri}" )" "${api_params}" | jq -c .
}
