#!/bin/bash
#
# gitlab-tools:bin/gitlab-bash-api/put.sh
#
# Based on GitLab documentation:
#  https://docs.gitlab.com/ee/api/
#  https://docs.gitlab.com/ce/api/
#  https://gitlab.com/gitlab-org/gitlab-ce/tree/master/lib/api
#  https://docs.gitlab.com/ce/api/projects.html
#
if [ "$( type -t normalize_uri )" != 'function' ] ; then
  # shellcheck disable=SC1090
  source "$( dirname "${BASH_SOURCE[0]}" )/utils.sh" || exit 1
fi

function gitlab_put_raw {
  local -r api_uri="$1"
  local -r api_params="$2"
  #local -r curl_url="${GITLAB_URL_PREFIX}/api/${GITLAB_API_VERSION}/${api_uri}?per_page=${PER_PAGE_MAX}&${api_params}"
  local -r curl_url="${GITLAB_URL_PREFIX}/api/${GITLAB_API_VERSION}/${api_uri}?${api_params}"
  local    curl_result=

  if [ "${GITLAB_DEBUG}" = 'true' ] ; then
    cat <<EOF >&2
    curl --location --header "PRIVATE-TOKEN: ${GITLAB_PRIVATE_TOKEN}" -X PUT --silent "${curl_url}"
EOF
  fi

  curl_result="$(
    curl --location --header "PRIVATE-TOKEN: ${GITLAB_PRIVATE_TOKEN}" -X PUT --silent "${curl_url}"
    )"
  local -ri curl_rc=$?

  if [ ${curl_rc} -ne 0 ]; then
    echofatal "Error curl status ${curl_rc} : curl_url=${curl_url}" >&2
    return 1
  fi

  echo "${curl_result}"
}

#
# HTTP PUT - Read 1st returned page
#
function gitlab_put {
  local -r api_uri="$1"
  local -r api_params="$2"

  gitlab_put_raw "$( normalize_uri "${api_uri}" )" "${api_params}" | jq -c .
}

