#!/bin/bash
#
# gitlab-tools:bin/glt-api/utils-api.sh
#
if [ "$( type -t get_cachefile_if_valid )" != 'function' ] ; then
  # shellcheck disable=SC1090
  source "$( dirname "$( dirname "${BASH_SOURCE[0]}" )" )/utils/cache-api.sh" || exit 1
fi

function get_gitlab_profile {
  local -r gitlab="$1"

  if [ -n "${gitlab}" ] ; then
    echo "--gitlab ${gitlab}"
  fi
}

function call_gitlab {
  local -r gitlab="$1"
  shift
  local found=
  found="$( get_cachefile_if_valid "${gitlab}" "$@" )"

  if [ -n "${found}" ] ; then
    cat "${found}"
    return $?
  fi

  cat <<EOF >&2
  gitlab -o json $( get_gitlab_profile "${gitlab}" ) "$@"
EOF

  # shellcheck disable=SC2046
  gitlab -o json $( get_gitlab_profile "${gitlab}" ) "$@" |
    tee "$( get_cachefile "${gitlab}" "$@" )"
}

# pip3 list --format=json | jq '.[] | select( contains( .name = "python-gitlab") )'

# virtualenv -p python3 ~/.config/glt/env
# # shellcheck disable=SC1090
# source ~/.config/glt/env/bin/activate

if ! command -v gitlab >/dev/null ; then
  echofatal 'gitlab command not found.'
  exit 1
fi

case "$( gitlab --version )" in
  '2.3.1'|'2.4.0')
    ;;

  *)
    echowarn "python-gitlab version 2.3.1 is expected. Found: '$( gitlab --version )'" >&2
    ;;
esac

