#!/bin/bash
#
# gitlab-tools:bin/glx-projects-archived.sh
#

# Configuration - BEGIN
PROJECT_HOME="$( dirname "$( dirname "$( realpath "${BASH_SOURCE[0]}" )" )" )"
declare -r PROJECT_HOME

# shellcheck disable=SC1090
source "${PROJECT_HOME}/apis/bash-common-api/bash-common-api.sh" || exit 1

if is_variable_define_and_not_empty_safe 'GITLAB_BASH_API_PATH' ; then
  # shellcheck disable=SC1090
  source "${GITLAB_BASH_API_PATH}/init.sh" || exit 1
elif [ ! -f "${PROJECT_HOME}/bin/gitlab-bash-api/init.sh" ]; then
  echofatal "gitlab-bash-api/init.sh not found! - Please set GITLAB_BASH_API_PATH" >&2
  exit 1
else
  # shellcheck disable=SC1090
  source "${PROJECT_HOME}/bin/gitlab-bash-api/init.sh" || exit 1
fi
# Configuration - END

# Script start here
declare -gr ARCHIVED_DEFAULT='true'

function usage {
cat <<EOF
Get Request to GitLab

Usage:
  ${BASH_SOURCE[0]} --help
  ${BASH_SOURCE[0]} [archived true|false]

Action:
  -h,           --help  Display help message and exit
  -v BOOL,      --value BOOL, shared_runners_enabled BOOL
                        Request project where archived have given value
                        (default is: ${ARCHIVED_DEFAULT})

Samples:

    ${BASH_SOURCE[0]}
    ${BASH_SOURCE[0]} archived true

EOF
}

function main {
  local archived="${ARCHIVED_DEFAULT}"
  local param=

  while [ "$#" -gt 0 ] ; do
    param="$1"
    shift

    case "${param}" in
      '-h'|'--help') usage; exit 1;;

      '-v'|'--value'|'archived')
        archived="$( P "$@" )" && shift
        ;;

      *)
        echofatal "Unknown option: '${param}'"
        usage >&2
        exit 1
        ;;
    esac
  done

  if ! is_boolean "${archived}" ; then
    echofatal "Value must be a boolean: '${archived}'" >&2
    usage >&2
    exit 1
  fi

  "${PROJECT_HOME}/bin/glt-project.sh" list |
    jq "[ .[]
        | select( contains( .archived = ${archived} ) )
        | ${ARCHIVED_OUTPUT} ]" || exit 1
}

main "$@"
