#!/bin/bash
#
# gitlab-tools:bin/glx-projects-issues_enabled-without-issues.sh
#

# Configuration - BEGIN
PROJECT_HOME="$( dirname "$( dirname "$( realpath "${BASH_SOURCE[0]}" )" )" )"
declare -r PROJECT_HOME

# shellcheck disable=SC1090
source "${PROJECT_HOME}/apis/bash-common-api/bash-common-api.sh" || exit 1

if is_variable_define_and_not_empty_safe 'GITLAB_BASH_API_PATH' ; then
  # shellcheck disable=SC1090
  source "${GITLAB_BASH_API_PATH}/init.sh" || exit 1
elif [ ! -f "${PROJECT_HOME}/bin/gitlab-bash-api/init.sh" ]; then
  echofatal "gitlab-bash-api/init.sh not found! - Please set GITLAB_BASH_API_PATH" >&2
  exit 1
else
  # shellcheck disable=SC1090
  source "${PROJECT_HOME}/bin/gitlab-bash-api/init.sh" || exit 1
fi
# Configuration - END

# Script start here

function usage {
cat <<EOF
Get Request to GitLab

Usage:
  ${BASH_SOURCE[0]} --help
  ${BASH_SOURCE[0]}

Action:
  -h,           --help  Display help message and exit


Samples:

    ${BASH_SOURCE[0]}

EOF
}

function main {
  local param=

  while [ "$#" -gt 0 ] ; do
    param="$1"
    shift

    case "${param}" in
    '-h'|'--help') usage; exit 1;;

    *)
      echofatal "Unknown option: '${param}'" >&2
      usage >&2
      exit 1
      ;;
    esac
  done

  "${PROJECT_HOME}/bin/glt-project.sh" list |
    jq "[ .[]
        | select( contains( .issues_access_level = \"enabled\" ) )
        | select( contains( .open_issues_count = 0 ) )
        | ${ISSUES_ACCESS_LEVEL_OUTPUT} ]" || exit 1
}

main "$@"
