#!/bin/bash
#
# gitlab-tools:bin/glx-projects-shared-runners.sh
#

# Configuration - BEGIN
PROJECT_HOME="$( dirname "$( dirname "$( realpath "${BASH_SOURCE[0]}" )" )" )"
declare -r PROJECT_HOME

# shellcheck disable=SC1090
source "${PROJECT_HOME}/apis/bash-common-api/bash-common-api.sh" || exit 1

if is_variable_define_and_not_empty_safe 'GITLAB_BASH_API_PATH' ; then
  # shellcheck disable=SC1090
  source "${GITLAB_BASH_API_PATH}/init.sh" || exit 1
elif [ ! -f "${PROJECT_HOME}/bin/gitlab-bash-api/init.sh" ]; then
  echofatal "gitlab-bash-api/init.sh not found! - Please set GITLAB_BASH_API_PATH" >&2
  exit 1
else
  # shellcheck disable=SC1090
  source "${PROJECT_HOME}/bin/gitlab-bash-api/init.sh" || exit 1
fi
# Configuration - END

# Script start here
declare -gr SHARED_RUNNERS_ENABLED_DEFAULT='false'

function usage {
cat <<EOF
Get Request to GitLab

Usage:
  ${BASH_SOURCE[0]} --help
  ${BASH_SOURCE[0]} [shared_runners_enabled true|false]

Action:
  -h,           --help  Display help message and exit
  -v BOOL,      --value BOOL, shared_runners_enabled BOOL
                        Request project where shared_runners_enabled have given value
                        (default is: ${SHARED_RUNNERS_ENABLED_DEFAULT})

Samples:

    ${BASH_SOURCE[0]}
    ${BASH_SOURCE[0]} shared_runners_enabled true

EOF
}

function main {
  local param=
  local shared_runners_enabled="${SHARED_RUNNERS_ENABLED_DEFAULT}"

  while [ "$#" -gt 0 ] ; do
    param="$1"
    shift

    case "${param}" in
    '-h'|'--help') usage; exit 1;;

    '-v'|'--value'|'shared_runners_enabled')
      shared_runners_enabled="$( P "$@" )" && shift
      ;;

    *)
      echofatal "Unknown option: '${param}'" >&2
      usage >&2
      exit 1
      ;;
    esac
  done

  if ! is_boolean "${shared_runners_enabled}" ; then
    echofatal "Value must be a boolean: '${shared_runners_enabled}'" >&2
    usage >&2
    exit 1
  fi

  "${PROJECT_HOME}/bin/glt-project.sh" list |
    jq "[ .[]
        | select( contains( .shared_runners_enabled = ${shared_runners_enabled} ) )
        | select( contains( .jobs_enabled = true ) )
        | ${SHARED_RUNNERS_ENABLED_OUTPUT} ]" || exit 1
}

main "$@"
