#!/bin/bash
#
# gitlab-tools:bin/utils/common-utils.sh
#
if [ "$( type -t echofatal )" != 'function' ] ; then
  echo 'https://git.cclaude.rocks/bash-apis/bash-common-api is required: Function echofatal not found.' >&2
  exit 1
fi

function url_encode {
  # url_encode <string>
  local LANG=C i c e=''
  for ((i=0;i<${#1};i++)); do
    c=${1:$i:1}
    # shellcheck disable=SC1001
    [[ "$c" =~ [a-zA-Z0-9\.\~\_\-] ]] || printf -v c '%%%02X' "'$c"
    e+="$c"
  done
  echo "$e"
}

function build_html_encoded_from_parameters {
  local key=
  local value=

  while [ "$#" -gt 0 ] ; do
    if [ "$#" -eq 1 ] ; then
      echofatal "modify expect a (key,value) pairs. No value for '$1'"
      return 1
    fi

    key="$1"
    shift || exit 1

    value="$1"
    shift || exit 1

    echo -n "${key}=$( url_encode "${value}" )&"
  done
}

function build_html_encoded_from_json {
  local -r file="$1"
  local    json_content=
  local    json_entry=
  local    key=
  local    value=

  if [ ! -f "${file}" ] ; then
    echofatal "File not found: '${file}'."
    return 1
  fi

  if ! json_content="$( jq -c 'to_entries[]' "${file}" )" ; then
    echofatal "JSON File '${file}' not valid."
    return 1
  fi

  while read -r json_entry ; do
    key="$( jq -r '.key' <<<"${json_entry}" )"
    value="$( jq -r '.value' <<<"${json_entry}" )"

    echo -n "${key}=$( url_encode "${value}" )&"
  done <<<"${json_content}"
}

