#!/bin/bash
#
# gitlab-tools:config/glx-audit-config.sh
#

#
# Audit filter for groups
#
# Migration: GITLAB_DEFAULT_AUDIT_FOR_GROUP -> GITLAB_AUDIT_FILTER_FOR_GROUP
#
# shellcheck disable=SC2034
declare -g GITLAB_AUDIT_FILTER_FOR_GROUP='
id: .id,
web_url: .web_url,
name: .name,
path: .path,
description: .description,
visibility: .visibility,
share_with_group_lock: .share_with_group_lock,
require_two_factor_authentication: .require_two_factor_authentication,
two_factor_grace_period: .two_factor_grace_period,
project_creation_level: .project_creation_level,
auto_devops_enabled: .auto_devops_enabled,
subgroup_creation_level: .subgroup_creation_level,
emails_disabled: .emails_disabled,
lfs_enabled: .lfs_enabled,
avatar_url: .avatar_url,
request_access_enabled: .request_access_enabled,
full_name: .full_name,
full_path: .full_path,
parent_id: .parent_id
'

#
# Audit filter for projects
#
# By default, next values are ignored (not relevant for audit):
#  forks_count: .forks_count,
#  last_activity_at: .last_activity_at,
#  star_count: .star_count
#
# Migration: GITLAB_DEFAULT_AUDIT_FOR_PROJECT -> GITLAB_AUDIT_FILTER_FOR_PROJECT
#
# shellcheck disable=SC2034
declare -g GITLAB_AUDIT_FILTER_FOR_PROJECT='
id: .id,
description: .description,
name: .name,
name_with_namespace: .name_with_namespace,
path: .path,
path_with_namespace: .path_with_namespace,
created_at: .created_at,
default_branch: .default_branch,
tag_list: .tag_list,
ssh_url_to_repo: .ssh_url_to_repo,
http_url_to_repo: .http_url_to_repo,
web_url: .web_url,
readme_url: .readme_url,
avatar_url: .avatar_url,
namespace: {
  id: .namespace.id,
  name: .namespace.name,
  path: .namespace.path,
  kind: .namespace.kind,
  full_path: .namespace.full_path,
  parent_id: .namespace.parent_id,
  avatar_url: .namespace.avatar_url,
  web_url: .namespace.web_url
},
_links: {
  self: ._links.self,
  merge_requests: ._links.merge_requests,
  repo_branches: ._links.repo_branches,
  labels: ._links.labels,
  events: ._links.events,
  members: ._links.members
  },
empty_repo: .empty_repo,
archived: .archived,
visibility: .visibility,
resolve_outdated_diff_discussions: .resolve_outdated_diff_discussions,
container_registry_enabled: .container_registry_enabled,
issues_enabled: .issues_enabled,
merge_requests_enabled: .merge_requests_enabled,
wiki_enabled: .wiki_enabled,
jobs_enabled: .jobs_enabled,
snippets_enabled: .snippets_enabled,
issues_access_level: .issues_access_level,
repository_access_level: .repository_access_level,
merge_requests_access_level: .merge_requests_access_level,
wiki_access_level: .wiki_access_level,
builds_access_level: .builds_access_level,
snippets_access_level: .snippets_access_level,
shared_runners_enabled: .shared_runners_enabled,
lfs_enabled: .lfs_enabled,
creator_id: .creator_id,
import_status: .import_status,
ci_default_git_depth: .ci_default_git_depth,
public_jobs: .public_jobs,
build_timeout: .build_timeout,
auto_cancel_pending_pipelines: .auto_cancel_pending_pipelines,
build_coverage_regex: .build_coverage_regex,
ci_config_path: .ci_config_path,
shared_with_groups: .shared_with_groups,
only_allow_merge_if_pipeline_succeeds: .only_allow_merge_if_pipeline_succeeds,
request_access_enabled: .request_access_enabled,
only_allow_merge_if_all_discussions_are_resolved: .only_allow_merge_if_all_discussions_are_resolved,
remove_source_branch_after_merge: .remove_source_branch_after_merge,
printing_merge_request_link_enabled: .printing_merge_request_link_enabled,
merge_method: .merge_method,
auto_devops_enabled: .auto_devops_enabled,
auto_devops_deploy_strategy: .auto_devops_deploy_strategy,
permissions: {
  project_access: .permissions.project_access,
  group_access: {
    access_level: .permissions.group_access.access_level,
    notification_level: .permissions.group_access.notification_level
  }
}
'


# tag_list: .tag_list[],
# namespace: .namespace[],
# shared_with_groups: .shared_with_groups[],
# permissions: .permissions[]

#created_at:                                      2017-07-11T07:35:24.223Z",
#last_activity_at:                                2017-08-20T08:55:33.186Z",

#namespace:                                          {
#  id:
#  name:
#  path:
#  kind:
#    },
#shared_with_groups:                                [],

#permissions:                                          {
#  project_access:                                          null,
#  group_access:                                          {
#    access_level:                                          40,
#    notification_level:                                          3
#      }
#    }

