glt commands
============

## glt-branch

`python-gitlab` wrapper for GitLab branches

Sample:

```bash
glt-branch
```

More details using `glt-branch --help`


## glt-group

`python-gitlab` wrapper for GitLab groups for read operations, write operations
are handled by `gitlab-bash-api`.

### Usage

```
glt-group [options] action
```

More details using `glt-group --help`

#### Action

```
  -h, --help            Display help message and exit
  group ID              Get group by id (alias for id)
  id ID                 Get group by id
  list                  List all groups
  name NAME             Get group by name

  modify ID KEY VALUE [KEY VALUE]...
                        Modify group configuration. ID (an integer) is
                        the group ID. KEY and VALUE must be pair of key
                        and value to modify

  put ID DATA           Modify group configuration. ID (an integer) is
                        the group ID. DATA must be an URL encoded string.

  search STR            Search groups having STR in text fields (name, path, full_name,
                        full_path and description).

  search-by-name STR    Search groups having STR in name and path fields only (name, path,
                        full_name, full_path)
```

#### Options

```
  -g GITLAB, --gitlab GITLAB
                        Which configuration section should be used. If not
                        defined, the default selection will be used. (python-gitlab)
```

### Samples

Get all groups configuration:

```bash
glt-group list
```

Get configuration of private groups:

```bash
glt-group list | jq '[ .[] | select( .visibility == "private" ) ]'
```

Get URL of public groups (output is simple text, one URL by line):

```bash
glt-group list | jq -r '.[] | select( .visibility == "public" ) | .web_url'
```

Get JSON array of internal groups URL's:

```bash
glt-group list | jq  '[ .[] | select( .visibility == "internal" ) | .web_url ]'
```

Search group by string:

```bash
glt-group search SOMETHING | jq '.[].id'
```

Modify group configuration. Set new description and set attribute lfs_enabled to false:

```bash
glt-group modify 50 description 'my configuration' lfs_enabled false
```

Modify group configuration (using URL encoded format):

```bash
glt-group put 50 'description=my%20configuration&lfs_enabled=false'
```

### Related API documentation

* [Groups API](https://docs.gitlab.com/ee/api/groups.html),
* [Groups API (update)](https://docs.gitlab.com/ee/api/groups.html#update-group) for modify


## glt-project

`python-gitlab` wrapper for GitLab projects

### Usage

```
glt-project [options] action
```

More details using `glt-project --help`

#### Action

```
  -h, --help            Display help message and exit
  group ID              List all projects within given group id.
  id ID                 Display project with given project id.
  list                  List all projects
  name NAME             Display project with given project name

  modify ID KEY VALUE [KEY VALUE]...
                        Modify project configuration. ID (an integer) is
                        the project ID. KEY and VALUE must be pair of key
                        and value to modify

  put ID DATA           Modify project configuration. ID (an integer) is
                        the project ID. DATA must be an URL encoded string.

  search STR            Search projects having STR in text fields (name, path, tag_list
                        and description).

  search-by-name STR    Search projects having STR in name and path fields only (name, path)
```

#### Options

```
  -g GITLAB, --gitlab GITLAB
                        Which configuration section should be used. If not
                        defined, the default selection will be used. (python-gitlab)
```

### Samples

Get all projects configuration:

```bash
glt-project list
```

Search project by string:

```bash
glt-project search DNS
```

Modify project configuration. Set new description and set attribute remove_source_branch_after_merge to true:

```bash
glt-project modify 3 description 'DNS configuration' remove_source_branch_after_merge true
```

Modify project configuration (using URL encoded format):

```bash
glt-project put 3 'description=DNS%20configuration&remove_source_branch_after_merge=true'
```

### Related API documentation

* [Projects API](https://docs.gitlab.com/ee/api/projects.html),
* [Projects API (edit)](https://docs.gitlab.com/ee/api/projects.html#edit-project) for modify


## glt-user

`python-gitlab` wrapper for GitLab users

```bash
glt-user list
```

```bash
glt-project search nathalie
```

-----

Return to [README](README.md)

