#!/bin/bash
#
#
#
set -u
set -o pipefail

PROJECT_HOME="$( dirname "$( dirname "$( realpath "${BASH_SOURCE[0]}" )" )" )"
declare -r PROJECT_HOME

function build_install_config_links_entries {
  local file=

  while read -r file ; do
    basename "${file%.sh}"
  done < <( find 'bin' -maxdepth 1 -type f -name 'gl*.sh' )
}

function build_install_config_exe_entries {
  find 'bin' -maxdepth 1 -type f -name 'gl*.sh'
  find '.'   -maxdepth 1 -type f -name 'gitlab-tools-*.sh' -exec basename "{}" \;
}

function build_install_config {
  cat <<'EOF'
#!/bin/bash -e
# shellcheck disable=SC2034
#
# gitlab-tools:bin/install-config.sh
#

#
# Accoring to: http://www.pathname.com/fhs/pub/fhs-2.3.html
#
# Put everything into: /usr/local/share/kdeconnect_tools
# Ensure *.sh are executables and readonly
# Add links into: /usr/bin
#
declare -r INSTALL_DATA_DIR='/usr/local/share/gitlab-tools'
declare -r INSTALL_BIN_DIR='/usr/bin'

declare -r REMOVE_OLD="${INSTALL_DATA_DIR}/gitlab-tools-remove"
declare -r REMOVE_EXE="${INSTALL_DATA_DIR}/gitlab-tools-remove.sh"

EOF

  cat <<EOF
declare -r INSTALL_LINKS='
$( build_install_config_links_entries | sort )
'

declare -r INSTALL_EXE='
$( build_install_config_exe_entries | sort )
'
EOF

  cat <<'EOF'

declare -ra INSTALL_PACKAGES=( curl git jq )
EOF
}

function main {
  cd "${PROJECT_HOME}" || exit 1

  if [ -f 'bin/install-config.sh' ] ; then
    mv -vf 'bin/install-config.sh' 'bin/install-config.sh~'
  fi

  build_install_config >'bin/install-config.sh'
}

main "$@"
